@@ -17,8 +17,10 @@ class TasksPlugin(hildondesktop.HomeItem):
 	def __init__(self):
 		hildondesktop.HomeItem.__init__(self)
 		
-		if(self._prefRead('autosize')=='1'):
+		if(int(self._prefRead('autosize'))==1):
 			self.set_resize_type(hildondesktop.HOME_ITEM_RESIZE_BOTH)
+		else:
+			self.set_resize_type(hildondesktop.HOME_ITEM_RESIZE_NONE)
 
 		self.connect("settings", self._DoSettings)
 
@@ -205,8 +207,10 @@ class TasksPlugin(hildondesktop.HomeItem):
 			self.timer = None
 
 	def foreground(self, widget, data=None):
-		if(self._prefRead('autosize')=='1'):
+		if(int(self._prefRead('autosize'))==1):
 			self.set_resize_type(hildondesktop.HOME_ITEM_RESIZE_BOTH)
+		else:
+			self.set_resize_type(hildondesktop.HOME_ITEM_RESIZE_NONE)
 			
 		self.label.modify_font(pango.FontDescription (self._prefRead('font')))
 		self.label.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse(self._prefRead('background')))
